Django jrac
===========


Requirements
------------

`Django <https://www.djangoproject.com/>`_ 1.3 or later


Installation
------------

::

    $ pip install django-jquery


Setup
-----

Add ``'django.contrib.staticfiles'``, ``'jquery'``, ``'jquery_ui'``, and ``'jrac'`` to INSTALLED_APPS in
your settings.py::

    INSTALLED_APPS = (
        # ...

        'django.contrib.staticfiles',
        'jquery',
        'jquery_ui'
        'jrac',

        # ...
    )

Make sure you use ``'collectstatic'`` to copy installed files to your static folder::

    $ python setup.py collectstatic

Refer to Django `static files <https://docs.djangoproject.com/en/dev/howto/static-files/>`_
documentation for additional information.


Usage
-----

You can refer to jquery in your template with::

    {{ STATIC_URL }}js/jquery.jrac.js


Custom widget::

    class MyWidget(forms.TextInput):
        class Media:
            js = ('js/jquery.jrac.js',)

        def render(self, name, value, attrs=None):
            html = super(MyWidget, self).render(name, value, attrs=attrs)
            # ...
            return html

Deployment::

    Use the minified jquery.jrac.min.js instead of jquery.jrac.js


Demo
----

Check out the `demo <http://www.trepmag.ch/z/jrac/example/>`_.

